==> libtcod_1.18.1+dfsg.orig.tar.xz: libtcod-1.18.1/samples/rad/rad_shader.cpp <==
/*
 * Photon reactor
 * Copyright (c) 2011 Jice
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *     * Redistributions of source code must retain the above copyright
 *       notice, this list of conditions and the following disclaimer.
 *     * Redistributions in binary form must reproduce the above copyright
 *       notice, this list of conditions and the following disclaimer in the
 *       documentation and/or other materials provided with the distribution.
 *     * The names of Jice may not be used to endorse or promote products
 *       derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY JICE ``AS IS'' AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL JICE BE LIABLE FOR ANY
 * DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
#include "rad_shader.hpp"

#include <libtcod.h>

void Shader::init(TCODMap* map) {
  this->map = map;
  int size = map->getWidth() * map->getHeight();
  lightmap = new TCODColor[size];
}

int Shader::addLight(int x, int y, int radius, const TCODColor& col) {
  int id = static_cast<int>(lights.size());
  Light l;
  l.x = x;
  l.y = y;
  l.radius = radius;
  l.col = col;
  lights.push_back(l);
  return id;
}

void Shader::updateLight(int id, int x, int y, int radius, const TCODColor& col) {
  Light& l = lights.at(id);
  l.x = x;
  l.y = y;
  l.radius = radius;
  l.col = col;
}

const TCODColor& Shader::getLightColor(int x, int y) { return lightmap[x + y * map->getWidth()]; }

==> libtcod_1.24.0+dfsg.orig.tar.xz: libtcod-1.24.0/samples/rad/rad_shader.cpp <==
/*
 * Photon reactor
 * Copyright (c) 2011 Jice
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *     * Redistributions of source code must retain the above copyright
 *       notice, this list of conditions and the following disclaimer.
 *     * Redistributions in binary form must reproduce the above copyright
 *       notice, this list of conditions and the following disclaimer in the
 *       documentation and/or other materials provided with the distribution.
 *     * The names of Jice may not be used to endorse or promote products
 *       derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY JICE ``AS IS'' AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL JICE BE LIABLE FOR ANY
 * DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
#include "rad_shader.hpp"

#include <libtcod.hpp>

void Shader::init(TCODMap* map) {
  this->map_ = map;
  const int size = map->getWidth() * map->getHeight();
  lightmap_ = new TCODColor[size];
}

int Shader::addLight(int x, int y, int radius, const TCODColor& col) {
  const int id = static_cast<int>(lights_.size());
  Light l;
  l.x = x;
  l.y = y;
  l.radius = radius;
  l.col = col;
  lights_.push_back(l);
  return id;
}

void Shader::updateLight(int id, int x, int y, int radius, const TCODColor& col) {
  Light& l = lights_.at(id);
  l.x = x;
  l.y = y;
  l.radius = radius;
  l.col = col;
}

const TCODColor& Shader::getLightColor(int x, int y) { return lightmap_[x + y * map_->getWidth()]; }
